﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace PrintScreenNotification
{
    public partial class Form2 : Form
    {
        int SaveExt = 0;
        int Form_W = 0;
        int Form_H = 0;
        string SaveDir = "";
        string PS_day = "";

        public Form2()
        {
            InitializeComponent();
        }

        private void Form2_Load(object sender, EventArgs e)
        {
            Microsoft.Win32.RegistryKey regkey = Microsoft.Win32.Registry.CurrentUser.CreateSubKey(@"Software\PrintScreenNotification", false);
            SaveDir = (string)regkey.GetValue("Directory"); //保存場所
            PS_day = (string)regkey.GetValue("LastTime"); //PrintScreenキーが押された日付
            SaveExt = (int)regkey.GetValue("SaveExt");  //拡張子インデックス
            regkey.Close();

            //フォームの横と高さを記憶
            Form_W = this.Width;
            Form_H = this.Height;

            // ウィンドウを画面右下に表示させる
            int left = Screen.PrimaryScreen.WorkingArea.Width - Form_W;
            int top = Screen.PrimaryScreen.WorkingArea.Height - Form_H;
            DesktopBounds = new Rectangle(left, top, Form_W, Form_H);

            pictureBox2.Image = System.Windows.Forms.Clipboard.GetImage();

            Task t1 = new Task(AutoClose);
            t1.Start();

        }

        public delegate void MoveWindowHandler();
        public void MoveWindow()
        {
            //右にスライド
            for (int x = 1; x <= Form_W; ++x)
            {
                Thread.Sleep(0);
                int left = Screen.PrimaryScreen.WorkingArea.Width - this.Width + x;
                int top = Screen.PrimaryScreen.WorkingArea.Height - this.Height;
                DesktopBounds = new Rectangle(left, top, this.Width, this.Height);
            }
            button_Minimize.PerformClick();
        }

        public void AutoClose()
        {
            Thread.Sleep(5000);
            //Form2が存在していたら実行
            if (Application.OpenForms.OfType<Form2>().Count() == 1)
            {
                Invoke(new MoveWindowHandler(MoveWindow));
            }
        }

        public void button_Minimize_Click(object sender, EventArgs e)
        {
            //ウィンドウを画面右下に表示させる
            int left = Screen.PrimaryScreen.WorkingArea.Width - 44;
            int top = Screen.PrimaryScreen.WorkingArea.Height + 8;
            DesktopBounds = new Rectangle(left, top, 20, 20);
            //背景をグレーに
            //this.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(192)))), ((int)(((byte)(192)))), ((int)(((byte)(192)))));
            Show_Toast.Visible = true;
        }

        //フォームが閉じられるときに呼ばれる
        private void Form2_FormClosing(object sender, FormClosingEventArgs e)
        {
            pictureBox1.Image.Dispose();
            pictureBox1.Image = null;
            pictureBox2.Image.Dispose();
            pictureBox2.Image = null;
        }

        private void Save_as_Click(object sender, EventArgs e)
        {
            //別名保存
            System.Windows.Forms.SaveFileDialog sfd = new System.Windows.Forms.SaveFileDialog();
            sfd.FileName = PS_day;
            sfd.Filter = Properties.Resources.std_filter;
            sfd.FilterIndex = SaveExt + 2;
            sfd.InitialDirectory = SaveDir;
            sfd.Title = Properties.Resources.newsave;
            sfd.RestoreDirectory = true;
            if (sfd.ShowDialog() == DialogResult.OK)
            {
                string extension = Path.GetExtension(sfd.FileName);
                switch (extension.ToUpper())
                {
                    case ".BMP":
                        pictureBox2.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Bmp);
                        break;
                    case ".GIF":
                        pictureBox2.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Gif);
                        break;
                    case ".JPG":
                        pictureBox2.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Jpeg);
                        break;
                    case ".PNG":
                        pictureBox2.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Png);
                        break;
                    case ".TIFF":
                        pictureBox2.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Tiff);
                        break;
                }
            }
            this.Close();
        }

        private void Save_Click(object sender, EventArgs e)
        {
            //保存
            //PrintScreenNotification_Images.拡張子をPrintScreenキーを押した日付に変えて
            //保存するフォルダに移動する

            //レジストリから拡張子情報を読み込んだ値を基に拡張子設定
            string SaveExtValue = "png";
            switch (SaveExt)
            {
                case 0:
                    SaveExtValue = "bmp";
                    break;
                case 1:
                    SaveExtValue = "gif";
                    break;
                case 2:
                    SaveExtValue = "jpg";
                    break;
                case 3:
                    SaveExtValue = "png";
                    break;
                case 4:
                    SaveExtValue = "tiff";
                    break;
            }
            pictureBox2.Image.Save(SaveDir + "\\" + PS_day + "." + SaveExtValue);
            this.Close();
        }

        //保存フォルダを開く
        private void Open_folder_Click(object sender, EventArgs e)
        {
            System.Diagnostics.Process.Start(SaveDir);
            this.Close();
        }

        //トースト表示
        private void Show_Toast_Click(object sender, EventArgs e)
        {
            int left = Screen.PrimaryScreen.WorkingArea.Width - Form_W;
            int top = Screen.PrimaryScreen.WorkingArea.Height - Form_H;
            DesktopBounds = new Rectangle(left, top, Form_W, Form_H);
            Show_Toast.Visible = false;
        }

        //×ボタンを押すと閉じる
        private void button1_Click(object sender, EventArgs e)
        {
            this.Close();
        }
    }
}
