﻿using Microsoft.Toolkit.Uwp.Notifications;
using System;
using System.Drawing;
using System.IO;
using System.Windows.Forms;
using Windows.Data.Xml.Dom;
using Windows.UI.Notifications;

namespace PrintScreenNotificationCore
{
    public partial class Form1 : Form
    {
        int SaveExt = 0;
        static string fimgpaths = Path.GetTempPath() + "PrintScreenNotification_Images.png";
        string SaveDir = "";
        string PS_day = "";

        /// <summary>
        /// 指定したファイルをロックせずに、System.Drawing.Imageを作成する。
        /// </summary>
        /// <param name="filename">作成元のファイルのパス</param>
        /// <returns>作成したSystem.Drawing.Image。</returns>
        public static System.Drawing.Image CreateImage(string filename)
        {
            System.IO.FileStream fs = new System.IO.FileStream(
                filename,
                System.IO.FileMode.Open,
                System.IO.FileAccess.Read);
            System.Drawing.Image img = System.Drawing.Image.FromStream(fs);
            fs.Close();
            return img;
        }


        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            //PrintScreenNotification_Images.png
            //なかったら終了
            if (!File.Exists(fimgpaths)) {
                Application.Exit();
            }
            Form1.Form1Instance = this;
            Microsoft.Win32.RegistryKey regkey = Microsoft.Win32.Registry.CurrentUser.CreateSubKey(@"Software\PrintScreenNotification", false);
            SaveDir = (string)regkey.GetValue("Directory"); //保存場所
            PS_day = (string)regkey.GetValue("LastTime"); //PrintScreenキーが押された日付
            SaveExt = (int)regkey.GetValue("SaveExt");  //拡張子インデックス
            regkey.Close();
            pictureBox1.Image = CreateImage(fimgpaths);
            File.Delete(fimgpaths);
        }

        //Form1を外部から呼び出すためのインスタンス設定
        private static Form1 _form1Instance;
        public static Form1 Form1Instance
        {
            get
            {
                return _form1Instance;
            }
            set
            {
                _form1Instance = value;
            }
        }

        //デリゲート
        delegate void SetFocusDelegate();
        public void action_newfile()
        {
            Invoke(new SetFocusDelegate(SDOpen));
        }
        public void action_savefile()
        {
            Invoke(new SetFocusDelegate(Imagsave));
        }
        public void action_openfolder()
        {
            Invoke(new SetFocusDelegate(FOpen));
        }

        /////トースト上のボタンを押したときの処理
        //別名保存
        //SaveDirectory(名前を付けて保存)を開く
        void SDOpen()
        {
            button1.GetType().InvokeMember("OnClick", System.Reflection.BindingFlags.InvokeMethod | System.Reflection.BindingFlags.NonPublic | System.Reflection.BindingFlags.Instance, null, button1, new object[] { EventArgs.Empty });
        }
        //保存
        //PrintScreenNotification_Images.拡張子をPrintScreenキーを押した日付に変えて
        //保存するフォルダに移動する
        void Imagsave()
        {
            //レジストリから拡張子情報を読み込んだ値を基に拡張子設定
            string SaveExtValue = "png";
            switch (SaveExt)
            {
                case 0:
                    SaveExtValue = "bmp";
                    break;
                case 1:
                    SaveExtValue = "gif";
                    break;
                case 2:
                    SaveExtValue = "jpg";
                    break;
                case 3:
                    SaveExtValue = "png";
                    break;
                case 4:
                    SaveExtValue = "tiff";
                    break;
            }
            pictureBox1.Image.Save(SaveDir + "\\" + PS_day + "." + SaveExtValue);
            Application.Exit();
        }
        //フォルダを開く
        //保存するフォルダを開く
        void FOpen()
        {
            System.Diagnostics.Process.Start(SaveDir);
            Application.Exit();
        }

        internal void button1_Click(object sender, EventArgs e)
        {
            //別名保存
            System.Windows.Forms.SaveFileDialog sfd = new System.Windows.Forms.SaveFileDialog();
            sfd.FileName = PS_day;
            sfd.Filter = Properties.Resources.std_filter;
            sfd.FilterIndex = SaveExt + 2;
            sfd.InitialDirectory = SaveDir;
            sfd.Title = Properties.Resources.newsave;
            sfd.RestoreDirectory = true;
            if (sfd.ShowDialog() == DialogResult.OK)
            {
                string extension = Path.GetExtension(sfd.FileName);
                switch (extension.ToUpper())
                {
                    case ".BMP":
                        pictureBox1.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Bmp);
                        break;
                    case ".GIF":
                        pictureBox1.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Gif);
                        break;
                    case ".JPG":
                        pictureBox1.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Jpeg);
                        break;
                    case ".PNG":
                        pictureBox1.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Png);
                        break;
                    case ".TIFF":
                        pictureBox1.Image.Save(sfd.FileName, System.Drawing.Imaging.ImageFormat.Tiff);
                        break;
                }
            }
            Application.Exit();
        }
    }
}
